//
//
// C++ Interface: $MODULE$
//
// Description:
//
//
// Author: Christian Hubinger <chubinger@irrsinnig.org>, (C) 2003
//
// Copyright: See COPYING file that comes with this distribution
//
//
/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/


#ifndef KMFGENERICINTERFACENAT_H
#define KMFGENERICINTERFACENAT_H

#include <kmyfirewallgenericinterfacenatwidget.h>

// TQt Includes
#include <tqguardedptr.h>

/**
@author Christian Hubinger
*/

namespace KMF {
class KMFNetwork;
class KMFGenericDoc;
class NetfilterObject;

class KMFGenericInterfaceNat : public KMyFirewallGenericInterfaceNATWidget {
	TQ_OBJECT
  
public:
	KMFGenericInterfaceNat( TQWidget *parent = 0, const char *name = 0, WFlags f = 0 );

	~KMFGenericInterfaceNat();
signals:


public slots:
	void slotUpdateView();
	void slotUpdateView( NetfilterObject* );

public:
	void loadDoc( KMFNetwork* );


private:
	TQGuardedPtr<KMFNetwork> m_doc;	

    private slots: void slotAddressChanged( const TQString& );
    private slots: void slotMasqueradeEnabled( bool );
    private slots: void slotNatEnabled( bool );
    private slots: void slotExternalInterfaceChanged( const TQString& );
};
}
#endif
